==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/tour/messages/sv/base.php <==
<?php
return array (
  ' Remove panel' => 'Ta bort panelen',
  '<strong>Account</strong> Menu' => '<strong> Konto </strong> -meny',
  '<strong>Getting</strong> Started' => '<strong> Komma </strong> igång',
  '<strong>Guide:</strong> Administration (Modules)' => '<strong> Guide: </strong> Administration (moduler)',
  '<strong>Guide:</strong> Overview' => '<strong>Guide:</strong> Översikt',
  '<strong>Guide:</strong> Spaces' => '<strong>Guide:</strong> Nätverk',
  '<strong>Guide:</strong> User profile' => '<strong>Guide:</strong> Användarprofil',
  '<strong>Notifications</strong>' => '<strong>Aviseringar</strong>',
  '<strong>Remove</strong> tour panel' => '<strong>Ta bort</strong> guide-panelen',
  '<strong>Space</strong> Menu' => '<strong>Nätverks</strong> meny',
  '<strong>Start</strong> space guide' => '<strong>Starta</strong> nätverksguide',
  'Cancel' => 'Avbryt',
  'Don\'t lose track of things!<br /><br />This icon will keep you informed of activities and posts that concern you directly.' => 'Håll koll på saker! <br><br> Den här ikonen håller dig informerad om aktiviteter och inlägg som berör dig.',
  'Drag a photo here or click to browse your files' => 'Dra hit ett foto eller klicka för att bläddra bland dina filer',
  'End guide' => 'Avsluta guide',
  'Get to know your way around the site\'s most important features with the following guides:' => 'Lär känna verktygets viktigaste funktioner med följande guider:',
  'Hide my year of birth' => 'Dölj min födelsedag',
  'Howdy <strong>%firstname%</strong>, thank you for using %community%.' => 'Halloj <strong>% förnamn% </strong>, tack för att du använder% community%.',
  'Next »' => 'Nästa »',
  'Ok' => 'Ok',
  'Save and close' => 'Spara och stäng',
  'The account menu gives you access to your private settings and allows you to manage your public profile.' => 'Kontomenyn ger dig åtkomst till dina privata inställningar och låter dig hantera din offentliga profil.',
  'This action will remove the tour panel from your dashboard. You can reactivate it at<br>Account settings <i class="fa fa-caret-right"></i> Settings.' => 'Den här åtgärden tar bort guide-panelen från din tidslinje. Du kan återaktivera den i <br> Inställningar för kontot <i class="fa fa-caret-right"> </i> Inställningar.',
  'This is the most important menu and will probably be the one you use most often!<br><br>Access all the spaces you have joined and create new spaces here.<br><br>The next guide will show you how:' => 'Det här är den viktigaste menyn och den kommer förmodligen att vara den du använder oftast! <br><br> Besök alla nätverk du har gått med i och skapa nya utrymmen. <br><br> Nästa guide visar hur:',
  'You are the first user here... Yehaaa! Be a shining example and complete your profile,<br>so that future users know who is the top dog here and to whom they can turn to if they have questions.' => 'Du är den första användaren här ... Tjohoo! Var ett föredöme och fyll i din profil, <br> så att användare som ansluter senare vet vem som är den lysande stjärnan här och till vem de kan vända sig till om de har frågor.',
  'Your firstname' => 'Ditt förnamn',
  'Your lastname' => 'Ditt efternamn',
  'Your mobile phone number' => 'Ditt mobilnummer',
  'Your phone number at work' => 'Ditt telefonnummer på jobbet',
  'Your skills, knowledge and experience (comma seperated)' => 'Dina färdigheter, kunskaper och erfarenheter (kommaseparerade)',
  'Your title or position' => 'Din titel eller position',
  '« Prev' => '« Föregående',
);

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/tour/messages/sv/base.php <==
<?php
return array (
  ' Remove panel' => 'Ta bort panelen',
  '<strong>Account</strong> Menu' => '<strong> Konto </strong> -meny',
  '<strong>Getting</strong> Started' => '<strong> Komma </strong> igång',
  '<strong>Guide:</strong> Administration (Modules)' => '<strong> Guide: </strong> Administration (moduler)',
  '<strong>Guide:</strong> Overview' => '<strong>Guide:</strong> Översikt',
  '<strong>Guide:</strong> Spaces' => '<strong>Guide:</strong> Forum',
  '<strong>Guide:</strong> User profile' => '<strong>Guide:</strong> Användarprofil',
  '<strong>Notifications</strong>' => '<strong>Aviseringar</strong>',
  '<strong>Remove</strong> tour panel' => '<strong>Ta bort</strong> guide-panelen',
  '<strong>Space</strong> Menu' => '<strong>Forum</strong> meny',
  '<strong>Start</strong> space guide' => '<strong>Starta</strong> forumguide',
  'Cancel' => 'Avbryt',
  'Don\'t lose track of things!<br /><br />This icon will keep you informed of activities and posts that concern you directly.' => 'Håll koll på saker! <br><br> Den här ikonen håller dig informerad om aktiviteter och inlägg som berör dig.',
  'Drag a photo here or click to browse your files' => 'Dra hit ett foto eller klicka för att bläddra bland dina filer',
  'End guide' => 'Avsluta guide',
  'Get to know your way around the site\'s most important features with the following guides:' => 'Lär känna verktygets viktigaste funktioner med följande guider:',
  'Hide my year of birth' => 'Dölj min födelsedag',
  'Howdy <strong>%firstname%</strong>, thank you for using %community%.' => 'Halloj <strong>% förnamn% </strong>, tack för att du använder% community%.',
  'Next »' => 'Nästa »',
  'Ok' => 'Ok',
  'Save and close' => 'Spara och stäng',
  'The account menu gives you access to your private settings and allows you to manage your public profile.' => 'Kontomenyn ger dig åtkomst till dina privata inställningar och låter dig hantera din offentliga profil.',
  'This action will remove the tour panel from your dashboard. You can reactivate it at<br>Account settings <i class="fa fa-caret-right"></i> Settings.' => 'Den här åtgärden tar bort guide-panelen från din tidslinje. Du kan återaktivera den i <br> Inställningar för kontot <i class="fa fa-caret-right"> </i> Inställningar.',
  'This is the most important menu and will probably be the one you use most often!<br><br>Access all the spaces you have joined and create new spaces here.<br><br>The next guide will show you how:' => 'Det här är den viktigaste menyn och den kommer förmodligen att vara den du använder oftast! <br><br> Besök alla forum du har gått med i och skapa nya utrymmen. <br><br> Nästa guide visar hur:',
  'You are the first user here... Yehaaa! Be a shining example and complete your profile,<br>so that future users know who is the top dog here and to whom they can turn to if they have questions.' => 'Du är den första användaren här ... Tjohoo! Var ett föredöme och fyll i din profil, <br> så att användare som ansluter senare vet vem som är den lysande stjärnan här och till vem de kan vända sig till om de har frågor.',
  'Your firstname' => 'Ditt förnamn',
  'Your lastname' => 'Ditt efternamn',
  'Your mobile phone number' => 'Ditt mobilnummer',
  'Your phone number at work' => 'Ditt telefonnummer på jobbet',
  'Your skills, knowledge and experience (comma seperated)' => 'Dina färdigheter, kunskaper och erfarenheter (kommaseparerade)',
  'Your title or position' => 'Din titel eller position',
  '« Prev' => '« Föregående',
);
